==> clive_0.4.14.orig.tar.gz: clive-0.4.14/src/clive/__init__.py <==
# -*- coding: ascii -*-

###########################################################################
# clive, video extraction utility
# Copyright (C) 2007-2008 Toni Gundogdu
#
# clive is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 0.1.2-1307 USA
###########################################################################

__version__ = \
'0.4.14'

__version_alphanum__ = \
''

__version_str__ = \
'clive/' + __version__ + __version_alphanum__

__date__ = \
'2008-05-26'

__author__ = \
'Toni Gundogdu <legatvsgmailcom>'

__url__ = \
'https://gna.org/projects/clive/'

__notice__ = \
'Copyright (C) 2007-2008 Toni Gundogdu.\n' \
'clive comes with NO WARRANTY, to the extent permitted by law.\n' \
'You may redistribute copies of clive under the terms of the\n' \
'GNU General Public License. For more information about these\n' \
'matters, see the files named COPYING.'

__newt_version__ = \
'0.52.9'

==> clive_0.4.19.orig.tar.gz: clive-0.4.19/src/clive/__init__.py <==
# -*- coding: ascii -*-

###########################################################################
# clive, video extraction utility
# Copyright (C) 2007-2008 Toni Gundogdu
#
# clive is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 0.1.2-1307 USA
###########################################################################

__version__ = \
'0.4.19'

__version_alphanum__ = \
''

__version_str__ = \
'clive/' + __version__ + __version_alphanum__

__date__ = \
'2008-07-22'

__author__ = \
'Toni Gundogdu <bugs>'

__url__ = \
'https://gna.org/projects/clive/'

__notice__ = \
'Copyright (C) 2007-2008 Toni Gundogdu. clive comes with NO WARRANTY,\n' \
'to the extent permitted by law. You may redistribute copies of clive\n' \
'under the terms of the GNU General Public License. For more\n' \
'information about these matters, see the files named COPYING.'

__newt_version__ = \
'0.52.9'
